from abstract_utilities import lazy_import
#PyQt6
QtWidgets = lazy_import("abstract_gui.QT6", "QtWidgets")
QtGui = lazy_import("abstract_gui.QT6", "QtGui")
QtCore = lazy_import("abstract_gui.QT6", "QtCore")
QtGui = lazy_import("abstract_gui.QT6", "QtGui")
QtWidgets = lazy_import("abstract_gui.QT6", "QtWidgets")
QWidget = lazy_import("abstract_gui.QT6", "QWidget")
QVBoxLayout = lazy_import("abstract_gui.QT6", "QVBoxLayout")
QHBoxLayout = lazy_import("abstract_gui.QT6", "QHBoxLayout")
lazy_import("abstract_gui.QT6")
#QtGui
QGuiApplication = lazy_import("abstract_gui.QT6", "QGuiApplication")
QClipboard = lazy_import("abstract_gui.QT6", "QClipboard")
#QtWidgets
QMessageBox = lazy_import("abstract_gui.QT6", "QMessageBox")
QApplication = lazy_import("abstract_gui.QT6", "QApplication")
QTextEdit = lazy_import("abstract_gui.QT6", "QTextEdit")
QMainWindow = lazy_import("abstract_gui.QT6", "QMainWindow")
#QtCore
Qt = lazy_import("abstract_gui.QT6", "Qt")



    


